{
{ "pgband" }, {
{ "read cursor position, with anchor" },
{ "Syntax" },
{ "      INTEGER FUNCTION PGBAND (MODE, POSN, XREF, YREF, X, Y, CH)" },
{ "      INTEGER MODE, POSN" },
{ "      REAL XREF, YREF, X, Y" },
{ "      CHARACTER*(*) CH" },
{ "" },
{ "Read the cursor position and a character typed by the user." },
{ "The position is returned in world coordinates.  PGBAND positions" },
{ "the cursor at the position specified (if POSN=1), allows the user to" },
{ "move the cursor using the mouse or arrow keys or whatever is available" },
{ "on the device. When he has positioned the cursor, the user types a" },
{ "single character on the keyboard; PGBAND then returns this" },
{ "character and the new cursor position (in world coordinates)." },
{ "" },
{ "Some interactive devices offer a selection of cursor types," },
{ "implemented as thin lines that move with the cursor, but without" },
{ "erasing underlying graphics. Of these types, some extend between" },
{ "a stationary anchor-point at XREF,YREF, and the position of the" },
{ "cursor, while others simply follow the cursor without changing shape" },
{ "or size. The cursor type is specified with one of the following MODE" },
{ "values. Cursor types that are not supported by a given device, are" },
{ "treated as MODE=0." },
{ "" },
{ "-- If MODE=0, the anchor point is ignored and the routine behaves" },
{ "like PGCURS." },
{ "-- If MODE=1, a straight line is drawn joining the anchor point " },
{ "and the cursor position." },
{ "-- If MODE=2, a hollow rectangle is extended as the cursor is moved," },
{ "with one vertex at the anchor point and the opposite vertex at the" },
{ "current cursor position; the edges of the rectangle are horizontal" },
{ "and vertical." },
{ "-- If MODE=3, two horizontal lines are extended across the width of" },
{ "the display, one drawn through the anchor point and the other" },
{ "through the moving cursor position. This could be used to select" },
{ "a Y-axis range when one end of the range is known." },
{ "-- If MODE=4, two vertical lines are extended over the height of" },
{ "the display, one drawn through the anchor point and the other" },
{ "through the moving cursor position. This could be used to select an" },
{ "X-axis range when one end of the range is known." },
{ "-- If MODE=5, a horizontal line is extended through the cursor" },
{ "position over the width of the display. This could be used to select" },
{ "an X-axis value such as the start of an X-axis range. The anchor point" },
{ "is ignored." },
{ "-- If MODE=6, a vertical line is extended through the cursor" },
{ "position over the height of the display. This could be used to select" },
{ "a Y-axis value such as the start of a Y-axis range. The anchor point" },
{ "is ignored." },
{ "-- If MODE=7, a cross-hair, centered on the cursor, is extended over" },
{ "the width and height of the display. The anchor point is ignored." },
{ "" },
{ "Returns:" },
{ " PGBAND          : 1 if the call was successful; 0 if the device" },
{ "                   has no cursor or some other error occurs." },
{ "Arguments:" },
{ " MODE   (input)  : display mode (0, 1, ..7: see above)." },
{ " POSN   (input)  : if POSN=1, PGBAND attempts to place the cursor" },
{ "                   at point (X,Y); if POSN=0, it leaves the cursor" },
{ "                   at its current position. (On some devices this" },
{ "                   request may be ignored.)" },
{ " XREF   (input)  : the world x-coordinate of the anchor point." },
{ " YREF   (input)  : the world y-coordinate of the anchor point." },
{ " X      (in/out) : the world x-coordinate of the cursor." },
{ " Y      (in/out) : the world y-coordinate of the cursor." },
{ " CH     (output) : the character typed by the user; if the device has" },
{ "                   no cursor or if some other error occurs, the value" },
{ "                   CHAR(0) [ASCII NUL character] is returned." },
{ "" },
{ "Note: The cursor coordinates (X,Y) may be changed by PGBAND even if" },
{ "the device has no cursor or if the user does not move the cursor." },
{ "Under these circumstances, the position returned in (X,Y) is that of" },
{ "the pixel nearest to the requested position." },
{ "" },
{ "" }
}
},
{
{ "pgbeg" }, {
{ "open a graphics device" },
{ "Syntax" },
{ "      INTEGER FUNCTION PGBEG (UNIT, FILE, NXSUB, NYSUB)" },
{ "      INTEGER       UNIT" },
{ "      CHARACTER*(*) FILE" },
{ "      INTEGER       NXSUB, NYSUB" },
{ "" },
{ "Note: new programs should use PGOPEN rather than PGBEG. PGOPEN" },
{ "is retained for compatibility with existing programs. Unlike PGOPEN," },
{ "PGBEG closes any graphics devices that are already open, so it " },
{ "cannot be used to open devices to be used in parallel." },
{ "" },
{ "PGBEG opens a graphical device or file and prepares it for" },
{ "subsequent plotting. A device must be opened with PGBEG or PGOPEN" },
{ "before any other calls to PGPLOT subroutines for the device." },
{ "" },
{ "If any device  is already open for PGPLOT output, it is closed before" },
{ "the new device is opened." },
{ "" },
{ "Returns:" },
{ " PGBEG         : a status return value. A value of 1 indicates" },
{ "                   successful completion, any other value indicates" },
{ "                   an error. In the event of error a message is" },
{ "                   written on the standard error unit.  " },
{ "                   To test the return value, call" },
{ "                   PGBEG as a function, eg IER=PGBEG(...); note" },
{ "                   that PGBEG must be declared INTEGER in the" },
{ "                   calling program. Some Fortran compilers allow" },
{ "                   you to use CALL PGBEG(...) and discard the" },
{ "                   return value, but this is not standard Fortran." },
{ "Arguments:" },
{ " UNIT  (input)   : this argument is ignored by PGBEG (use zero)." },
{ " FILE  (input)   : the \"device specification\" for the plot device." },
{ "                   (For explanation, see description of PGOPEN.)" },
{ " NXSUB  (input)  : the number of subdivisions of the view surface in" },
{ "                   X (&gt;0 or &lt;0)." },
{ " NYSUB  (input)  : the number of subdivisions of the view surface in" },
{ "                   Y (&gt;0)." },
{ "                   PGPLOT puts NXSUB x NYSUB graphs on each plot" },
{ "                   page or screen; when the view surface is sub-" },
{ "                   divided in this way, PGPAGE moves to the next" },
{ "                   panel, not the  next physical page. If" },
{ "                   NXSUB &gt; 0, PGPLOT uses the panels in row" },
{ "                   order; if &lt;0, PGPLOT uses them in column order." },
{ "" },
{ "" }
}
},
{
{ "pgcurs" }, {
{ "read cursor position" },
{ "Syntax" },
{ "      INTEGER FUNCTION PGCURS (X, Y, CH)" },
{ "      REAL X, Y" },
{ "      CHARACTER*(*) CH" },
{ "" },
{ "Read the cursor position and a character typed by the user." },
{ "The position is returned in world coordinates.  PGCURS positions" },
{ "the cursor at the position specified, allows the user to move the" },
{ "cursor using the joystick or arrow keys or whatever is available on" },
{ "the device. When he has positioned the cursor, the user types a" },
{ "single character on the keyboard; PGCURS then returns this" },
{ "character and the new cursor position (in world coordinates)." },
{ "" },
{ "Returns:" },
{ " PGCURS         : 1 if the call was successful; 0 if the device" },
{ "                   has no cursor or some other error occurs." },
{ "Arguments:" },
{ " X      (in/out) : the world x-coordinate of the cursor." },
{ " Y      (in/out) : the world y-coordinate of the cursor." },
{ " CH     (output) : the character typed by the user; if the device has" },
{ "                   no cursor or if some other error occurs, the value" },
{ "                   CHAR(0) [ASCII NUL character] is returned." },
{ "" },
{ "Note: The cursor coordinates (X,Y) may be changed by PGCURS even if" },
{ "the device has no cursor or if the user does not move the cursor." },
{ "Under these circumstances, the position returned in (X,Y) is that of" },
{ "the pixel nearest to the requested position." },
{ "" },
{ "" }
}
},
{
{ "pgopen" }, {
{ "open a graphics device" },
{ "Syntax" },
{ "      INTEGER FUNCTION PGOPEN (DEVICE)" },
{ "      CHARACTER*(*) DEVICE" },
{ "" },
{ "Open a graphics device for PGPLOT output. If the device is" },
{ "opened successfully, it becomes the selected device to which" },
{ "graphics output is directed until another device is selected" },
{ "with PGSLCT or the device is closed with PGCLOS." },
{ "" },
{ "The value returned by PGOPEN should be tested to ensure that" },
{ "the device was opened successfully, e.g.," },
{ "" },
{ "      ISTAT = PGOPEN('plot.ps/PS')" },
{ "      IF (ISTAT .LE. 0 ) STOP" },
{ "" },
{ "Note that PGOPEN must be declared INTEGER in the calling program." },
{ "" },
{ "The DEVICE argument is a character constant or variable; its value" },
{ "should be one of the following:" },
{ "" },
{ "(1) A complete device specification of the form 'device/type' or" },
{ "    'file/type', where 'type' is one of the allowed PGPLOT device" },
{ "    types (installation-dependent) and 'device' or 'file' is the " },
{ "    name of a graphics device or disk file appropriate for this type." },
{ "    The 'device' or 'file' may contain '/' characters; the final" },
{ "    '/' delimits the 'type'. If necessary to avoid ambiguity," },
{ "    the 'device' part of the string may be enclosed in double" },
{ "    quotation marks." },
{ "(2) A device specification of the form '/type', where 'type' is one" },
{ "    of the allowed PGPLOT device types. PGPLOT supplies a default" },
{ "    file or device name appropriate for this device type." },
{ "(3) A device specification with '/type' omitted; in this case" },
{ "    the type is taken from the environment variable PGPLOT_TYPE," },
{ "    if defined (e.g., setenv PGPLOT_TYPE PS). Because of possible" },
{ "    confusion with '/' in file-names, omitting the device type" },
{ "    in this way is not recommended." },
{ "(4) A blank string (' '); in this case, PGOPEN will use the value" },
{ "    of environment variable PGPLOT_DEV as the device specification," },
{ "    or '/NULL' if the environment variable is undefined." },
{ "(5) A single question mark, with optional trailing spaces ('?'); in" },
{ "    this case, PGPLOT will prompt the user to supply the device" },
{ "    specification, with a prompt string of the form" },
{ "        'Graphics device/type (? to see list, default XXX):'" },
{ "    where 'XXX' is the default (value of environment variable" },
{ "    PGPLOT_DEV)." },
{ "(6) A non-blank string in which the first character is a question" },
{ "    mark (e.g., '?Device: '); in this case, PGPLOT will prompt the" },
{ "    user to supply the device specification, using the supplied" },
{ "    string as the prompt (without the leading question mark but" },
{ "    including any trailing spaces)." },
{ "" },
{ "In cases (5) and (6), the device specification is read from the" },
{ "standard input. The user should respond to the prompt with a device" },
{ "specification of the form (1), (2), or (3). If the user types a " },
{ "question-mark in response to the prompt, a list of available device" },
{ "types is displayed and the prompt is re-issued. If the user supplies" },
{ "an invalid device specification, the prompt is re-issued. If the user" },
{ "responds with an end-of-file character, e.g., ctrl-D in UNIX, program" },
{ "execution is aborted; this  avoids the possibility of an infinite" },
{ "prompting loop.  A programmer should avoid use of PGPLOT-prompting" },
{ "if this behavior is not desirable." },
{ "" },
{ "The device type is case-insensitive (e.g., '/ps' and '/PS' are " },
{ "equivalent). The device or file name may be case-sensitive in some" },
{ "operating systems." },
{ "" },
{ "Examples of valid DEVICE arguments:" },
{ "" },
{ "(1)  'plot.ps/ps', 'dir/plot.ps/ps', '\"dir/plot.ps\"/ps', " },
{ "     'user:[tjp.plots]plot.ps/PS'" },
{ "(2)  '/ps'      (PGPLOT interprets this as 'pgplot.ps/ps')" },
{ "(3)  'plot.ps'  (if PGPLOT_TYPE is defined as 'ps', PGPLOT" },
{ "                 interprets this as 'plot.ps/ps')" },
{ "(4)  '   '      (if PGPLOT_DEV is defined)" },
{ "(5)  '?  '" },
{ "(6)  '?Device specification for PGPLOT: '" },
{ "" },
{ "[This routine was added to PGPLOT in Version 5.1.0. Older programs" },
{ "use PGBEG instead.]" },
{ "" },
{ "Returns:" },
{ " PGOPEN          : returns either a positive value, the" },
{ "                   identifier of the graphics device for use with" },
{ "                   PGSLCT, or a 0 or negative value indicating an" },
{ "                   error. In the event of error a message is" },
{ "                   written on the standard error unit." },
{ "Arguments:" },
{ " DEVICE  (input) : the 'device specification' for the plot device" },
{ "                   (see above)." },
{ "" },
{ "" }
}
},
{
{ "pgrnd" }, {
{ "find the smallest `round' number greater than x" },
{ "Syntax" },
{ "      REAL FUNCTION PGRND (X, NSUB)" },
{ "      REAL X" },
{ "      INTEGER NSUB" },
{ "" },
{ "Routine to find the smallest \"round\" number larger than x, a" },
{ "\"round\" number being 1, 2 or 5 times a power of 10. If X is negative," },
{ "PGRND(X) = -PGRND(ABS(X)). eg PGRND(8.7) = 10.0," },
{ "PGRND(-0.4) = -0.5.  If X is zero, the value returned is zero." },
{ "This routine is used by PGBOX for choosing  tick intervals." },
{ "" },
{ "Returns:" },
{ " PGRND         : the \"round\" number." },
{ "Arguments:" },
{ " X      (input)  : the number to be rounded." },
{ " NSUB   (output) : a suitable number of subdivisions for" },
{ "                   subdividing the \"nice\" number: 2 or 5." },
{ "" },
{ "" }
}
},
{
{ "pgunsa" }, {
{ "restore PGPLOT attributes" },
{ "Syntax" },
{ "      ENTRY PGUNSA" },
{ "" },
{ "This routine restores the PGPLOT attributes saved in the last call to" },
{ "PGSAVE. Usage: CALL PGUNSA (no arguments). See PGSAVE." },
{ "" },
{ "Arguments: none" },
{ "" },
{ "" }
}
},
{
{ "pgbegin" }, {
{ "non-standard alias for PGBEG" },
{ "Syntax" },
{ "      INTEGER FUNCTION PGBEGIN (UNIT, FILE, NXSUB, NYSUB)" },
{ "      INTEGER       UNIT" },
{ "      CHARACTER*(*) FILE" },
{ "      INTEGER       NXSUB, NYSUB" },
{ "" },
{ "See description of PGBEG.   " },
{ "" },
{ "" }
}
},
{
{ "pgcurse" }, {
{ "non-standard alias for PGCURS" },
{ "Syntax" },
{ "      INTEGER FUNCTION PGCURSE (X, Y, CH)" },
{ "      REAL X, Y" },
{ "      CHARACTER*1 CH" },
{ "" },
{ "See description of PGCURS." },
{ "" },
{ "" }
}
},
